@@ -38,7 +38,12 @@ if not os.environ.get('PARSONS_SKIP_IMPORT_ALL'):
     from parsons.databases.postgres.postgres import Postgres
     from parsons.freshdesk.freshdesk import Freshdesk
     from parsons.bill_com.bill_com import BillCom
+    from parsons.newmode.newmode import Newmode
     from parsons.databases.mysql.mysql import MySQL
+    from parsons.rockthevote.rtv import RockTheVote
+    from parsons.mailchimp.mailchimp import Mailchimp
+    from parsons.zoom.zoom import Zoom
+    from parsons.action_network.action_network import ActionNetwork
 
     __all__ = [
         'VAN',
@@ -71,7 +76,12 @@ if not os.environ.get('PARSONS_SKIP_IMPORT_ALL'):
         'Postgres',
         'Freshdesk',
         'BillCom',
-        'MySQL'
+        'Newmode',
+        'MySQL',
+        'RockTheVote',
+        'Mailchimp',
+        'Zoom',
+        'ActionNetwork',
     ]
 
 # Define the default logging config for Parsons and its submodules. For now the
