@@ -101,16 +101,20 @@ class Redshift(RedshiftCreateTable, RedshiftCopyTable, RedshiftTableUtilities, R
         conn = psycopg2.connect(user=self.username, password=self.password,
                                 host=self.host, dbname=self.db, port=self.port,
                                 connect_timeout=self.timeout)
-        yield conn
+        try:
+            yield conn
 
-        conn.commit()
-        conn.close()
+            conn.commit()
+        finally:
+            conn.close()
 
     @contextmanager
     def cursor(self, connection):
         cur = connection.cursor(cursor_factory=psycopg2.extras.DictCursor)
-        yield cur
-        cur.close()
+        try:
+            yield cur
+        finally:
+            cur.close()
 
     def query(self, sql, parameters=None):
         """
@@ -731,6 +735,13 @@ class Redshift(RedshiftCreateTable, RedshiftCopyTable, RedshiftTableUtilities, R
             try:
                 # Copy to a staging table
                 logger.info(f'Building staging table: {staging_tbl}')
+                if 'compupdate' not in copy_args:
+                    # Especially with a lot of columns, compupdate=True can
+                    # cause a lot of processing/analysis by Redshift before upload.
+                    # Since this is a temporary table, setting compression for each
+                    # column is not impactful barely impactful
+                    # https://docs.aws.amazon.com/redshift/latest/dg/c_Loading_tables_auto_compress.html
+                    copy_args = dict(copy_args, compupdate=False)
                 self.copy(table_obj, staging_tbl,
                           template_table=target_table,
                           **copy_args)
