@@ -1,14 +1,16 @@
 import os
 import json
+import logging
+
+from parsons.etl.table import Table
+
 import gspread
 from oauth2client.service_account import ServiceAccountCredentials
-from parsons.etl.table import Table
-import logging
 
 logger = logging.getLogger(__name__)
 
 
-class GoogleSheets(object):
+class GoogleSheets:
     """
     A connector for Google Sheets, handling data import and export.
 
@@ -70,13 +72,13 @@ class GoogleSheets(object):
 
     def read_sheet(self, spreadsheet_id, sheet_index=0):
         """
-        Create a ```parsons table``` from a sheet in a Google spreadsheet, given the sheet index.
+        Create a ``parsons table`` from a sheet in a Google spreadsheet, given the sheet index.
 
         `Args:`
             spreadsheet_id: str
                 The ID of the spreadsheet (Tip: Get this from the spreadsheet URL)
             sheet_index: int (optional)
-                The index of the desired worksheet
+                The index of the desired worksheet (Index begins at 0).
 
         `Returns:`
             Parsons Table
@@ -84,7 +86,7 @@ class GoogleSheets(object):
         """
 
         sheet = self._get_sheet(spreadsheet_id, sheet_index)
-        records = sheet.get_all_records()
+        records = sheet.get_all_values()
 
         return Table(records)
 
@@ -106,6 +108,50 @@ class GoogleSheets(object):
         index = self.get_sheet_index_with_title(spreadsheet_id, title)
         return self.read_sheet(spreadsheet_id, index)
 
+    def share_spreadsheet(self, spreadsheet_id, sharee, share_type='user', role='reader',
+                          notify=True, notify_message=None, with_link=False):
+        """
+        Share a spreadsheet with a user, group of users, domain and/or the public.
+
+        `Args:`
+            spreadsheet_id: str
+                The ID of the spreadsheet (Tip: Get this from the spreadsheet URL)
+            sharee: str
+                User or group e-mail address, domain name to share the spreadsheet
+                with. To share publicly, set sharee value to ``None``.
+            share_type: str
+                The sharee type. Allowed values are: ``user``, ``group``, ``domain``,
+                ``anyone``.
+            role: str
+                The primary role for this user. Allowed values are: ``owner``,
+                ``writer``, ``reader``.
+            notify: boolean
+                Whether to send an email to the target user/domain.
+            email_message: str
+                The email to be sent if notify kwarg set to True.
+            with_link: boolean
+                Whether a link is required for this permission.
+        """
+
+        spreadsheet = self.gspread_client.open_by_key(spreadsheet_id)
+        spreadsheet.share(sharee, share_type, role, notify=notify,
+                          email_message=notify_message, with_link=with_link)
+
+    def get_spreadsheet_permissions(self, spreadsheet_id):
+        """
+        List the permissioned users and groups for a spreadsheet.
+
+        `Args:`
+            spreadsheet_id: str
+                The ID of the spreadsheet (Tip: Get this from the spreadsheet URL)
+        `Returns:`
+            Parsons Table
+                See :ref:`parsons-table` for output options.
+        """
+
+        spreadsheet = self.gspread_client.open_by_key(spreadsheet_id)
+        return Table(spreadsheet.list_permissions())
+
     def create_spreadsheet(self, title, editor_email=None):
         """
         Create a Google spreadsheet from a Parsons table. Optionally shares the new doc with
@@ -189,6 +235,10 @@ class GoogleSheets(object):
         # Maybe use gspread's low-level batch_update().
         existing_table = self.read_sheet(spreadsheet_id, sheet_index)
 
+        # If the existing sheet is blank, then just overwrite the table.
+        if existing_table.num_rows == 0:
+            return self.overwrite_sheet(spreadsheet_id, table, sheet_index, user_entered_value)
+
         cells = []
         for row_num, row in enumerate(table.data):
             for col_num, cell in enumerate(row):
